@@ -1,4 +1,4 @@
-use super::config::SortKey;
+use crate::session::*;
 use super::functions::*;
 use super::help::HELP;
 use super::nums::*;
@@ -25,6 +25,9 @@ pub fn run(arg: PathBuf) {
     let trash_dir = config_dir.join(PathBuf::from(TRASH));
     make_config(&config_file, &trash_dir)
         .unwrap_or_else(|_| panic!("cannot make config file or trash dir."));
+    let session_file = config_dir.join(PathBuf::from(SESSION_FILE));
+    make_session(&session_file)
+        .unwrap_or_else(|_| panic!("cannot make session file."));
 
     if !&arg.exists() {
         println!("Invalid path: {}", &arg.display());
@@ -59,29 +62,19 @@ pub fn run(arg: PathBuf) {
 
     let mut nums = Num::new();
 
-    debug!("starts screen.");
     let mut screen = screen::AlternateScreen::from(stdout().into_raw_mode().unwrap());
-    debug!("finished starting screen.");
 
     print!("{}", cursor::Hide);
-    debug!("cursor hidden.");
 
     clear_and_show(&state.current_dir);
-    debug!("clear_and_show finished.");
     state.list_up(nums.skip);
-    debug!("list_up finished.");
 
     state.move_cursor(&nums, STARTING_POINT);
-    debug!("move_cursor finished.");
-    match screen.flush() {
-        Ok(_) => debug!("first flush."),
-        Err(_) => error!("flush failed."),
-    }
+    screen.flush().unwrap();
 
     let mut p_memo_v: Vec<CursorMemo> = Vec::new();
     let mut c_memo_v: Vec<ChildMemo> = Vec::new();
     let mut stdin = stdin().keys();
-    debug!("finished initial setup.");
 
     'main: loop {
         let len = state.list.len();
@@ -1208,7 +1201,15 @@ pub fn run(arg: PathBuf) {
                         }
                     }
                 }
-
+                // Show/hide hidden files or directories
+                Key::Backspace => {
+                    state.show_hidden = !state.show_hidden;
+                    state.update_list();
+                    clear_and_show(&state.current_dir);
+                    state.list_up(0);
+                    nums.reset();
+                    state.move_cursor(&nums, STARTING_POINT);
+                }
                 _ => {
                     continue;
                 }
@@ -1218,4 +1219,5 @@ pub fn run(arg: PathBuf) {
     }
     //When finishes, restore the cursor
     print!("{}", cursor::Restore);
+    state.write_session(session_file);
 }
