@@ -1,12 +1,13 @@
+use super::session::*;
 use super::config::*;
 use super::functions::*;
 use super::nums::*;
 use chrono::prelude::*;
-use log::debug;
 use std::collections::HashMap;
 use std::collections::HashSet;
 use std::ffi::OsString;
 use std::fs;
+use std::fs::DirEntry;
 use std::io::{Error, ErrorKind};
 use std::path::{Path, PathBuf};
 use std::process::{Command, ExitStatus};
@@ -64,6 +65,7 @@ pub struct State {
     pub commands: HashMap<String, String>,
     pub sort_by: SortKey,
     pub layout: Layout,
+    pub show_hidden: bool,
 }
 
 #[derive(Debug, PartialEq, Eq, PartialOrd, Ord, Clone)]
@@ -95,6 +97,7 @@ pub struct Layout {
 impl Default for State {
     fn default() -> Self {
         let config = read_config().unwrap();
+        let session = read_session().unwrap();
         State {
             list: Vec::new(),
             registered: Vec::new(),
@@ -107,13 +110,14 @@ impl Default for State {
             ),
             default: config.default,
             commands: to_extension_map(&config.exec),
-            sort_by: config.sort_by,
+            sort_by: session.sort_by,
             layout: Layout {
                 terminal_row: 0,
                 terminal_column: 0,
                 name_max_len: 0,
                 time_start_pos: 0,
             },
+            show_hidden: session.show_hidden,
         }
     }
 }
@@ -538,7 +542,6 @@ impl State {
     }
 
     pub fn list_up(&self, skip_number: u16) {
-        debug!("list_up starts.");
         let row = self.layout.terminal_row;
         let len = self.list.len();
 
@@ -582,7 +585,7 @@ impl State {
     }
 
     pub fn update_list(&mut self) {
-        self.list = push_items(&self.current_dir, &self.sort_by).unwrap();
+        self.list = push_items(&self.current_dir, &self.sort_by, self.show_hidden).unwrap();
     }
 
     pub fn reset_selection(&mut self) {
@@ -614,10 +617,8 @@ impl State {
     pub fn move_cursor(&self, nums: &Num, y: u16) {
         print!("{}", cursor::Goto(1, self.layout.terminal_row));
         print!("{}", clear::CurrentLine);
-        debug!("move_cursor setup finished.");
 
         let item = self.get_item(nums.index);
-        debug!("get_item finished.");
         if let Ok(item) = item {
             match &item.file_ext {
                 Some(ext) => {
@@ -630,19 +631,26 @@ impl State {
                     );
                 }
                 None => {
-                    debug!("no extensions arm starts.");
                     print!(
                         "[{}/{}] {}",
                         nums.index + 1,
                         self.list.len(),
                         to_proper_size(item.file_size)
                     );
-                    debug!("no extensions arm finished.");
                 }
             }
         }
         print!("{}>{}", cursor::Goto(1, y), cursor::Left(1));
-        debug!("printing cursor finished.");
+    }
+
+    pub fn write_session(&self, session_path: PathBuf) {
+        let session = Session{
+            sort_by: self.sort_by.clone(),
+            show_hidden: self.show_hidden
+        };
+        let serialized = toml::to_string(&session).unwrap();
+        fs::write(&session_path, serialized)
+            .unwrap_or_else(|_| panic!("cannot write new session file."));
     }
 }
 
@@ -698,13 +706,24 @@ fn make_item(dir: fs::DirEntry) -> ItemInfo {
     }
 }
 
-pub fn push_items(p: &Path, key: &SortKey) -> Result<Vec<ItemInfo>, Error> {
+fn is_not_hidden(entry: &DirEntry) -> bool {
+    entry
+        .file_name()
+        .to_str()
+        .map(|s| !s.starts_with('.'))
+        .unwrap_or(false)
+}
+
+pub fn push_items(p: &Path, key: &SortKey, show_hidden: bool) -> Result<Vec<ItemInfo>, Error> {
     let mut result = Vec::new();
     let mut dir_v = Vec::new();
     let mut file_v = Vec::new();
 
     for entry in fs::read_dir(p)? {
         let e = entry?;
+        if !show_hidden && !is_not_hidden(&e) {
+            continue;
+        }
         let entry = make_item(e);
         match entry.file_type {
             FileType::Directory => dir_v.push(entry),
